@@ -2,6 +2,7 @@ import logging
 import os
 import pathlib
 import time
+import datetime
 from functools import wraps
 from typing import Dict, Iterable, Optional, Union, List
 
@@ -9,6 +10,7 @@ import git
 import toml
 from sortedcontainers import SortedDict
 
+
 from binsync.data import (
     Comment,
     Enum,
@@ -17,8 +19,9 @@ from binsync.data import (
     GlobalVariable,
     Patch,
     StackVariable,
-    Struct
+    Struct,
 )
+from binsync.data.artifact import TomlHexEncoder
 from binsync.core.errors import MetadataNotFoundError
 
 
@@ -62,7 +65,7 @@ def update_last_change(f):
 
         if not should_set:
             return f(self, *args, **kwargs)
-        artifact.last_change = int(time.time())
+        artifact.last_change = datetime.datetime.now(tz=datetime.timezone.utc)
 
         # Comment
         if isinstance(artifact, Comment):
@@ -165,13 +168,13 @@ class State:
     :ivar int version:  Version of the state, starting from 0.
     """
 
-    def __init__(self, user, version=None, client=None):
+    def __init__(self, user, version=None, client=None, last_push_time=None):
         # metadata info
         self.user = user  # type: str
         self.version = version if version is not None else 0  # type: int
         self.last_push_artifact = -1
         self.last_push_artifact_type = -1
-        self.last_push_time = -1
+        self.last_push_time = last_push_time or datetime.datetime.now(tz=datetime.timezone.utc)
 
         # the client
         self.client = client  # type: Optional[Client]
@@ -198,7 +201,7 @@ class State:
         return False
 
     def copy(self):
-        state = State(self.user, version=self.version, client=self.client)
+        state = State(self.user, version=self.version, client=self.client, last_push_time=self.last_push_time)
         state._dirty = False
         artifacts = ["functions", "comments", "structs", "patches", "global_vars", "enums"]
         for artifact in artifacts:
@@ -247,7 +250,7 @@ class State:
             "last_push_artifact": self.last_push_artifact,
             "last_push_artifact_type": self.last_push_artifact_type,
         }
-        self._dump_data(dst, 'metadata.toml', toml.dumps(d).encode())
+        self._dump_data(dst, 'metadata.toml', toml.dumps(d, encoder=TomlHexEncoder()).encode())
 
     def dump(self, dst: Union[pathlib.Path, git.IndexFile]):
         if isinstance(dst, str):
@@ -267,16 +270,16 @@ class State:
             self._dump_data(dst, path, struct.dump().encode())
 
         # dump comments
-        self._dump_data(dst, 'comments.toml', toml.dumps(Comment.dump_many(self.comments)).encode())
+        self._dump_data(dst, 'comments.toml', toml.dumps(Comment.dump_many(self.comments), encoder=TomlHexEncoder()).encode())
 
         # dump patches
-        self._dump_data(dst, 'patches.toml', toml.dumps(Patch.dump_many(self.patches)).encode())
+        self._dump_data(dst, 'patches.toml', toml.dumps(Patch.dump_many(self.patches), encoder=TomlHexEncoder()).encode())
 
         # dump global vars
-        self._dump_data(dst, 'global_vars.toml', toml.dumps(GlobalVariable.dump_many(self.global_vars)).encode())
+        self._dump_data(dst, 'global_vars.toml', toml.dumps(GlobalVariable.dump_many(self.global_vars), encoder=TomlHexEncoder()).encode())
 
         # dump enums
-        self._dump_data(dst, 'enums.toml', toml.dumps(Enum.dump_many(self.enums)).encode())
+        self._dump_data(dst, 'enums.toml', toml.dumps(Enum.dump_many(self.enums), encoder=TomlHexEncoder()).encode())
 
     @classmethod
     def parse(cls, src: Union[pathlib.Path, git.Tree], version=None, client=None):
@@ -293,6 +296,7 @@ class State:
             raise MetadataNotFoundError()
         state.user = metadata["user"]
         state.version = version if version is not None else metadata["version"]
+        state.last_push_time = metadata.get("last_push_time", None)
 
         # load functions
         function_files = list_files_in_dir(src, "functions", client=client)
@@ -430,12 +434,12 @@ class State:
             return False
 
         try:
-            old_var = func.stack_vars[variable.stack_offset]
+            old_var = func.stack_vars[variable.offset]
         except KeyError:
             old_var = None
 
         if old_var != variable:
-            func.stack_vars[variable.stack_offset] = variable
+            func.stack_vars[variable.offset] = variable
             return True
 
         return False
